@@ -4,7 +4,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.001003';
+our $VERSION = '0.002000';
 
 1;
 
@@ -20,7 +20,7 @@ WebService::MinFraud - BETA Perl API for MaxMind's minFraud Score and Insights w
 
 =head1 VERSION
 
-version 0.001003
+version 0.002000
 
 =head1 SYNOPSIS
 
@@ -96,7 +96,7 @@ Mateu Hunter <mhunter@maxmind.com>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Andy Jack Greg Oschwald
+=for stopwords Andy Jack Dave Rolsky Greg Oschwald
 
 =over 4
 
@@ -106,13 +106,17 @@ Andy Jack <ajack@maxmind.com>
 
 =item *
 
+Dave Rolsky <drolsky@maxmind.com>
+
+=item *
+
 Greg Oschwald <goschwald@maxmind.com>
 
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by MaxMind, Inc..
+This software is copyright (c) 2015 - 2016 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
