@@ -2,12 +2,14 @@ package WebService::MinFraud::Model::Insights;
 
 use Moo;
 
-our $VERSION = '0.001003';
+our $VERSION = '0.002000';
 
 use Types::Standard qw( HashRef InstanceOf );
 use WebService::MinFraud::Record::BillingAddress;
 use WebService::MinFraud::Record::Country;
 use WebService::MinFraud::Record::CreditCard;
+use WebService::MinFraud::Record::Device;
+use WebService::MinFraud::Record::Email;
 use WebService::MinFraud::Record::IPAddress;
 use WebService::MinFraud::Record::Issuer;
 use WebService::MinFraud::Record::Location;
@@ -22,13 +24,15 @@ with 'WebService::MinFraud::Role::Model',
     my %attribute_to_class = (
         billing_address  => 'WebService::MinFraud::Record::BillingAddress',
         credit_card      => 'WebService::MinFraud::Record::CreditCard',
+        device           => 'WebService::MinFraud::Record::Device',
+        email            => 'WebService::MinFraud::Record::Email',
         ip_address       => 'WebService::MinFraud::Record::IPAddress',
         shipping_address => 'WebService::MinFraud::Record::ShippingAddress',
     );
 
     foreach my $attribute ( keys %attribute_to_class ) {
         has $attribute => (
-            is  => 'ro',
+            is => 'ro',
             isa => InstanceOf [ $attribute_to_class{$attribute} ],
         );
     }
@@ -62,7 +66,7 @@ WebService::MinFraud::Model::Insights - Model class for minFraud Insights
 
 =head1 VERSION
 
-version 0.001003
+version 0.002000
 
 =head1 SYNOPSIS
 
@@ -85,6 +89,8 @@ version 0.001003
   my $postal     = $ip_address->postal;
   say $postal->code;
 
+  say $insights->device->id;
+
 =head1 DESCRIPTION
 
 This class provides a model for the data returned by the minFraud Insights web
@@ -114,6 +120,12 @@ credit card data for the transaction.
 Returns the I<approximate> number of service credits remaining on your account.
 The service credit counts are near realtime so they may not be exact.
 
+=head2 device
+
+Returns a L<WebService::MinFraud::Record::Device> object representing the
+device that MaxMind believes is associated with the IP address passed in the
+request.
+
 =head2 id
 
 Returns a UUID that identifies the minFraud request.  Please use this UUID in
@@ -186,7 +198,7 @@ Mateu Hunter <mhunter@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by MaxMind, Inc..
+This software is copyright (c) 2015 - 2016 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
