@@ -2,7 +2,7 @@ package WebService::MinFraud::Record::CreditCard;
 
 use Moo;
 
-our $VERSION = '0.001003';
+our $VERSION = '0.002000';
 
 use WebService::MinFraud::Record::Issuer;
 use WebService::MinFraud::Types
@@ -15,6 +15,12 @@ has issuer => (
     predicate => 1,
 );
 
+has brand => (
+    is        => 'ro',
+    isa       => Str,
+    predicate => 1,
+);
+
 has country => (
     is        => 'ro',
     isa       => Str,
@@ -35,6 +41,12 @@ has is_prepaid => (
     coerce  => BoolCoercion,
 );
 
+has type => (
+    is        => 'ro',
+    isa       => Str,
+    predicate => 1,
+);
+
 1;
 
 # ABSTRACT: Contains data for the credit card record associated with a transaction
@@ -49,7 +61,7 @@ WebService::MinFraud::Record::CreditCard - Contains data for the credit card rec
 
 =head1 VERSION
 
-version 0.001003
+version 0.002000
 
 =head1 SYNOPSIS
 
@@ -81,21 +93,33 @@ This class provides the following methods:
 
 Returns the L<WebService::MinFraud::Record::Issuer> object for the credit card.
 
+=head2 brand
+
+Returns the brand of the credit card, e.g. Visa, MasterCard, American Express etc.
+
 =head2 country
 
-Returns the L<ISO 3166-1 alpha 2 country
-code|http://en.wikipedia.org/wiki/ISO_3166-1_alpha-2> representing the country
-that the card was issued in.
+Returns the two letter L<ISO 3166-1 alpha 2 country
+code|http://en.wikipedia.org/wiki/ISO_3166-1_alpha-2> associated with the
+location of the majority of customers using this credit card as determined by
+their billing address. In cases where the location of customers is highly
+mixed, this defaults to the country of the bank issuing the card.
 
 =head2 is_issued_in_billing_address_country
 
-Returns a boolean indicating whether the issuer of the credit card is in the
-same country as the billing address.
+Returns a boolean indicating whether the country of the billing address
+matches the country of the majority of customers using this credit card. In
+cases where the location of customers is highly mixed, the match is to the
+country of the bank issuing the card.
 
 =head2 is_prepaid
 
 Returns a boolean indicating whether the credit card is prepaid.
 
+=head2 type
+
+Returns the type of the card if known: charge, credit or debit
+
 =head1 PREDICATE METHODS
 
 The following predicate methods are available, which return true if the related
@@ -111,7 +135,7 @@ Mateu Hunter <mhunter@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by MaxMind, Inc..
+This software is copyright (c) 2015 - 2016 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
