@@ -2,9 +2,10 @@ package WebService::MinFraud::Role::HasCommonAttributes;
 
 use Moo::Role;
 
-our $VERSION = '0.001003';
+our $VERSION = '0.002000';
 
 use Types::Standard qw( ArrayRef InstanceOf Num Str );
+use Types::UUID;
 use WebService::MinFraud::Record::Warning;
 use WebService::MinFraud::Types qw( NonNegativeInt );
 
@@ -12,7 +13,7 @@ requires 'raw';
 
 has id => (
     is        => 'lazy',
-    isa       => Str,
+    isa       => Uuid,
     init_arg  => undef,
     builder   => sub { $_[0]->raw->{id} },
     predicate => 1,
@@ -35,7 +36,7 @@ has credits_remaining => (
 );
 
 has warnings => (
-    is  => 'lazy',
+    is => 'lazy',
     isa => ArrayRef [ InstanceOf ['WebService::MinFraud::Record::Warning'] ],
     init_arg => undef,
     builder  => sub {
@@ -59,7 +60,7 @@ WebService::MinFraud::Role::HasCommonAttributes - A role for attributes common t
 
 =head1 VERSION
 
-version 0.001003
+version 0.002000
 
 =head1 AUTHOR
 
@@ -67,7 +68,7 @@ Mateu Hunter <mhunter@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by MaxMind, Inc..
+This software is copyright (c) 2015 - 2016 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
